@@ -1,174 +1,3 @@
-tfr.gelman.diag <- function(sim.dir=file.path(getwd(), 'bayesTFR.output'),
-							t.start=0, t.end=NULL, step=NULL, move.t0=TRUE,
-							par.names = tfr.parameter.names(trans=TRUE),
-							par.names.cs =tfr.parameter.names.cs(trans=TRUE),
-							file.name=paste('gelman.diag.', ifelse(move.t0, 't0', 't1'), '.txt', sep=''),
-							append=FALSE, verbose=TRUE) {
-	cat('\nComputing Gelman Diagnostics ... this can take a while ...')
-	mcmc.set <- get.tfr.mcmc(sim.dir=sim.dir, low.memory=TRUE)
-	N <- mcmc.set$mcmc.list[[1]]$finished.iter
-	if (is.null(t.end)) t.end <- N
-	if (is.null(step)) step <- max(1, ceiling((t.end-t.start)/10))
-	if (t.end > N) t.end <- max(N-step, 0)
-	full.file.name <- file.path(sim.dir, file.name)
-	
-	if (move.t0) {
-		t1 <- N
-	} else {
-		t0 <- 0
-	}
-	for (t.value in seq(t.start, t.end, by=step)) {
-		result <- c()
-		if (move.t0) {
-			t0 <- t.value
-			end <- t1-t0
-		} else {
-			t1 <- t.value
-			end <- t1
-		}
-		if (t0 == t1) next
-		if(verbose) {
-			cat('\n\nt0:', t0, 't1:', t1)
-			cat('\n\tLoad mcmc.')
-		}
-		mct0 <- get.tfr.mcmc(sim.dir=sim.dir, low.memory=TRUE)
-		if(verbose) 
-			cat('\n\tDiagnose country independent parameters.')
-		for (par.name in par.names) {
-			coda.mct0 <- coda.list.mcmc(mct0, rm.const.pars=TRUE, low.memory=TRUE, 
-								par.names=par.name, par.names.cs=NULL, burnin=t0, start=1, end=end)
-			npars <- ncol(coda.mct0[[1]])
-			if (!is.null(npars)) {
-				pnames <- colnames(coda.mct0[[1]])
-				for(ipar in 1:npars) {
-					coda.mct0.1par <- list()
-					for(ichain in 1:length(coda.mct0)) {
-						coda.mct0.1par[[ichain]] <- coda.mct0[[ichain]][,pnames[ipar]]
-					}
-					gd <- gelman.diag(coda.mct0.1par, autoburnin=FALSE)
-					result <- c(result, gd$psrf[1,1])
-				}
-			} else {
-				gd <- gelman.diag(coda.mct0, autoburnin=FALSE)
-				result <- c(result, gd$psrf[1,1])
-			}
-		}
-		all.names <- par.names
-		if(verbose)
-			cat('\n\tDiagnose country specific parameters: ')
-		for (par.name in par.names.cs) {
-			if(verbose)
-				cat(par.name, ', ')
-			for (country in mct0$meta$id_DL) {
-				coda.mct0 <- coda.list.mcmc(mct0, rm.const.pars=TRUE, low.memory=TRUE, 
-									par.names=NULL, par.names.cs=par.name, 
-									country=get.country.object(country, mct0$meta)$code,
-									burnin=t0, start=1, end=end)
-				if (length(coda.mct0) <= 0) next
-				npars <- ncol(coda.mct0[[1]])
-				pnames <- colnames(coda.mct0[[1]])
-				if (!is.null(npars)) {
-					for(ipar in 1:npars) {
-						coda.mct0.1par <- list()
-						for(ichain in 1:length(coda.mct0)) {
-							coda.mct0.1par[[ichain]] <- coda.mct0[[ichain]][,pnames[ipar]]
-						}
-						gd <- gelman.diag(coda.mct0.1par, autoburnin=FALSE)
-						result <- c(result, gd$psrf[1,1])
-					}
-				} else {
-					gd <- gelman.diag(coda.mct0, autoburnin=FALSE)
-					result <- c(result, gd$psrf[1,1])
-				}
-				all.names <- c(all.names, pnames)
-			}
-		}
-		result <- matrix(result, nrow=1)
-		result <- cbind(c(t.value), result)
-		colnames(result) <- c(ifelse(move.t0, 't0', 't1'), all.names)
-		if(verbose)
-			cat('\n\tWrite results into', full.file.name)
-		write.table(result, file=full.file.name, append=append, row.names=FALSE, 
-					col.names=!append)
-		if (!append) append <- TRUE
-	}
-	cat('\nFinished. Results stored in', full.file.name)
-	cat('\nUse tfr.plot.gelman to view results.\n')
-	invisible(read.table(full.file.name, header=TRUE))
-}
-
-tfr.plot.gelman <- function(data=NULL, 
-							file=file.path(getwd(), 'bayesTFR.output', 'gelman.diag.t0.txt'),
-							show.pars='slow', nr.pars=10, quant=0.95,
-							par.names=tfr.parameter.names(trans=TRUE),
-							min.burnin=0, max.burnin=NULL,
-							optimalR=1.1) {
-	if (is.null(data)) {
-		gelman.d <- read.table(file, header=TRUE)
-	} else {
-		gelman.d <- data
-	}
-	gelman.d <- gelman.d[gelman.d[,1]>=min.burnin,]
-	if (!is.null(max.burnin))
-		gelman.d <- gelman.d[gelman.d[,1]<=max.burnin,]
-	t0 <- gelman.d[,1]
-	t.name <- names(gelman.d)[1]
-	gelman.d <- gelman.d[,2:dim(gelman.d)[2]]
-	nr.all.pars <- dim(gelman.d)[2]
-	q <- apply(gelman.d, 1, quantile, quant)
-	if (!missing(par.names)) nr.pars <- length(par.names)
-	else {
-		if (show.pars == 'slow') {
-			maxR <- apply(gelman.d, 2, max)
-			o <- order(maxR, decreasing=TRUE)
-			par.names <- colnames(gelman.d)[o[1:min(nr.pars, nr.all.pars)]]
-		} else {
-			if (show.pars == 'quantile') {
-				par.names <- paste(100*quant, '%-th quantile')
-				nr.pars <- 1
-			} else nr.pars <- length(par.names)
-		}
-	}
-		
-		
-	cols <- c(1:6, colors()[seq(27, by=10, length=nr.pars)])
-	if (show.pars == 'quantile') {
-		values <- q
-	} else {
-		values <- gelman.d[,par.names[1]]
-	}
-	plot(t0, values, xlab=paste(t.name, '(burnin)'), ylab='Gelmans R', 
-			main='Gelman Diagnostics', type='b', ylim=c(min(gelman.d), 
-			max(gelman.d)), col=cols[1])
-	
-	if (length(par.names) > 1) {
-		for (ipname in 2:length(par.names)) {
-			lines(t0, gelman.d[,par.names[ipname]], col=cols[ipname], type='b')
-		}
-	}
-	abline(h=optimalR, lty=2)
-	legend('topright', legend=par.names, col=cols[1:nr.pars], bty='n', lty=1, pch='o')
-	
-	# find an optimal burnin
-	for(it0 in 1:length(t0)) {
-		if (show.pars == 'quantile') {
-			if (q[it0] <= optimalR)
-				break	
-		} else {
-			if (all(gelman.d[it0,] <= optimalR))
-				break
-		}
-	}
-	abline(v=t0[it0], lty=3, col='red')
-	if (show.pars != 'quantile') {
-		lines(t0, q, col='red', type='l', lty=4)
-		legend('topleft', legend=c('minimum burnin', paste(100*quant, '%-th quantile')), 
-					col='red', lty=c(3,4), bty='n')
-	} else {
-		legend('topleft', legend='minimum burnin', col='red', lty=3, bty='n')
-		}
-}
-
 tfr.raftery.diag <- function(mcmc=NULL, 
 							 sim.dir=file.path(getwd(), 'bayesTFR.output'),
 							 burnin=0, country=NULL,
@@ -498,7 +327,7 @@ process.not.converged.parameters <- function(diag, iter) {
 					nr.countries=nr.countries),
 				 class=class.name)
 	if(verbose) summary(diag)
-	save.dir <- file.path(sim.dir, 'diagnostics')
+	save.dir <- file.path(mcmc.set$meta$output.dir, 'diagnostics')
 	if(!file.exists(save.dir)) 
 		dir.create(save.dir, recursive=TRUE)
 	save.file <- do.call(paste('store.', class.name, sep=''), list(diag, thin=thin, burnin=burnin, 
@@ -511,7 +340,27 @@ tfr.diagnose <- function(sim.dir, thin=80, burnin=2000, express=FALSE,
 							country.sampling.prop=NULL, keep.thin.mcmc=FALSE, verbose=TRUE) {
 	invisible(.do.diagnose(type='tfr', class.name='bayesTFR.convergence', 
 							sim.dir=sim.dir, thin=thin, burnin=burnin, express=express,
-							country.sampling.prop=country.sampling.prop, keep.thin.mcmc=keep.thin.mcmc,							verbose=verbose))
+							country.sampling.prop=country.sampling.prop, keep.thin.mcmc=keep.thin.mcmc,	verbose=verbose))
+}
+
+tfr3.raftery.diag <- function(mcmc=NULL, 
+							 sim.dir=file.path(getwd(), 'bayesTFR.output'),
+							 burnin=0, country=NULL,
+							 par.names = tfr3.parameter.names(),
+							 par.names.cs = tfr3.parameter.names.cs(),
+							 country.sampling.prop=1,
+							 verbose=TRUE, ...) {
+	mcmc.set <- if (is.null(mcmc)) get.tfr3.mcmc(sim.dir=sim.dir, low.memory=TRUE) else mcmc
+	return(tfr.raftery.diag(mcmc=mcmc.set, burnin=burnin,
+						country=country, par.names=par.names, par.names.cs=par.names.cs,
+						country.sampling.prop=country.sampling.prop, verbose=verbose, ...))
+}
+
+tfr3.diagnose <- function(sim.dir, thin=60, burnin=10000, express=TRUE, 
+						country.sampling.prop=NULL, verbose=TRUE, ...) {
+	invisible(.do.diagnose(type='tfr3', class.name='bayesTFR.convergence', 
+							sim.dir=sim.dir, thin=thin, burnin=burnin, express=express,
+							country.sampling.prop=country.sampling.prop, keep.thin.mcmc=FALSE, verbose=verbose))
 }
 
 diag.thin.indep <- function(mcmc.list, q) {
